@@ -33,7 +33,7 @@ NaiveBayes.default <- function (x, grouping, prior = NULL, usekernel = FALSE, fL
         apriori <- as.table(prior / sum(prior))
     call <- match.call()
     Yname <- "grouping"
-    LaplaceEst <- function(x, f = 0)  (x + f)/(rowSums(x) + f * nlevels(var))
+    LaplaceEst <- function(x, f = 0)  (x + f)/(rowSums(x) + f * ncol(x))
 
     est <- function(var){
         if(is.numeric(var)) {
